<!-- 默认layout布局架构，左边菜单，头部与内容中间区域，返回顶部按钮 -->
<template>
  <el-container class="layout-container">
    <LayoutAside />
    <el-container class="layout-container-view h100">
      <el-scrollbar ref="layoutScrollbarRef" class="layout-backtop">
        <!-- <LayoutHeader /> -->
        <LayoutMain ref="layoutMainRef" />
      </el-scrollbar>
    </el-container>
  </el-container>
</template>

<script setup lang="ts" name="layoutDefaults">
import { defineAsyncComponent, nextTick, onMounted, ref, watch } from 'vue'
import { useThemeConfig } from '/@/stores/themeConfig'
import { storeToRefs } from 'pinia';
import { useRoute } from 'vue-router'
import { NextLoading } from '/@/utils/loading'
const LayoutAside = defineAsyncComponent(() => import('/@/layout/component/aside.vue'))//左边菜单
const LayoutHeader = defineAsyncComponent(() => import('/@/layout/component/header.vue'))//头部
const LayoutMain = defineAsyncComponent(() => import('/@/layout/component/main.vue'))//右边主要内容区域
const layoutScrollbarRef = ref<RefType>('')
const layoutMainRef = ref()
const route = useRoute()
const { themeConfig } = storeToRefs(useThemeConfig())
// 重置滚动条高度，由于组件是异步引入的
const initScrollBarHeight = () => {
  nextTick(() => {
    setTimeout(() => {
      updateScrollbar()
      console.log(layoutScrollbarRef.value)
      if (layoutScrollbarRef.value) {
        layoutScrollbarRef.value.wrap$.scrollTop = 0
      }
      if (layoutMainRef.value) {
        layoutMainRef.value.layoutMainScrollbarRef.wrap$.scrollTop = 0
      }
    }, 500);
  })
}
// 重置滚动条高度
const updateScrollbar = () => {
  // 更新父级 scrollbar
  layoutScrollbarRef.value?.update()
  // 更新子级 scrollbar
  layoutMainRef.value?.layoutMainScrollbarRef?.update() //layoutMainScrollbarRef为子级<el-scrollbar ref="layoutMainScrollbarRef"/>的ref
}
// 页面加载时
onMounted(() => {
  initScrollBarHeight()
  NextLoading.done(600)
})
// 监听路由的变化，切换界面时，滚动条置顶
watch(() => route.path, () => { initScrollBarHeight() })
// 监听 themeConfig 配置文件的变化，更新菜单 el-scrollbar 的高度
watch(themeConfig, () => { updateScrollbar() }, { deep: true })
</script>
<style lang='scss' scoped></style>